@@ -6,7 +6,7 @@ import Data.Kind
 
 data Proxy k (a :: k) = P
 
-x :: Proxy * Int
+x :: Proxy Type Int
 x = P
 
 y :: Proxy Bool True
