@@ -8,7 +8,7 @@ module Main where
 
 -- import Data.Generics
 import Data.Data hiding (Fixity)
-import Data.List
+import Data.List (intercalate)
 import System.IO
 import GHC
 import BasicTypes
@@ -17,7 +17,7 @@ import FastString
 import ForeignCall
 import MonadUtils
 import Outputable
-import HsDecls
+import GHC.Hs.Decls
 import Bag (filterBag,isEmptyBag)
 import System.Directory (removeFile)
 import System.Environment( getArgs )
